changeset 2004:ae5e9b0aded6

Further updates
author boisy
date Fri, 03 Mar 2006 18:07:56 +0000
parents 21ddb4118b6c
children 82198f9cd004
files 3rdparty/p2mods/noice/defsfile 3rdparty/p2mods/noice/makefile 3rdparty/p2mods/noice/noice.asm
diffstat 3 files changed, 19 insertions(+), 21 deletions(-) [+]
line wrap: on
line diff
--- a/3rdparty/p2mods/noice/defsfile	Fri Mar 03 12:57:04 2006 +0000
+++ b/3rdparty/p2mods/noice/defsfile	Fri Mar 03 18:07:56 2006 +0000
@@ -1,2 +1,3 @@
  use os9defs
  use scfdefs
+ use systype
--- a/3rdparty/p2mods/noice/makefile	Fri Mar 03 12:57:04 2006 +0000
+++ b/3rdparty/p2mods/noice/makefile	Fri Mar 03 18:07:56 2006 +0000
@@ -7,12 +7,10 @@
 BD              = ../../booters
 
 
-all:	calldbg_l1 calldbg_l2 krnp3_6309 krnp3_6809 krnp3_6309_mpi krnp3_6809_mpi noice noice_mpi
+all:	calldbg krnp3_6309 krnp3_6809 krnp3_6309_mpi krnp3_6809_mpi noice noice_mpi
 
-calldbg_l2: calldbg.asm
-	$(AS) $(ASOUT)$@ $< -aLevel=2 $(AFLAGS)
-
-calldbg_l1: calldbg.asm
+# calldbg works for both Level 1 and Level 2
+calldbg: calldbg.asm
 	$(AS) $(ASOUT)$@ $< -aLevel=1 $(AFLAGS)
 
 krnp3_6309: noice.asm
@@ -34,4 +32,4 @@
 	$(AS) $(ASOUT)$@ $< -aLevel=1 $(AFLAGS) -aMPI=1
 
 clean:
-	$(RM) calldbg_l1 calldbg_l2 krnp3_6309 krnp3_6809 krnp3_6309_mpi krnp3_6809_mpi noice noice_mpi
+	$(RM) calldbg krnp3_6309 krnp3_6809 krnp3_6309_mpi krnp3_6809_mpi noice noice_mpi
--- a/3rdparty/p2mods/noice/noice.asm	Fri Mar 03 12:57:04 2006 +0000
+++ b/3rdparty/p2mods/noice/noice.asm	Fri Mar 03 18:07:56 2006 +0000
@@ -51,9 +51,8 @@
 rev            SET       $00
 edition        SET       3
 
-* If an MPI is being used, set RS232SLOT to slot value - 1 and set MPI to 1
-MPICTRL        EQU       $FF7F
-RS232SLOT      EQU       1            slot 2
+* If an MPI is being used, set DEVICESLOT to slot value - 1 and set MPI to 1
+DEVICESLOT     EQU       1            slot 2
 
 *MPI            EQU       1
 
@@ -124,7 +123,7 @@
                bcs       ex@
                stu       <D.DbgMem           save our allocated memory
 * clear the firsttime flag so that the first time we get
-* called at dbgent, we DON'T subtract the SWI from the PC.
+* called at dbgent, we DO NOT subtract the SWI from the PC.
                sta       firsttime,u         A = $01
                IFGT      Level-1
 * Level > 1: get next KrnP module going
@@ -590,10 +589,10 @@
 ioinit                   
                IFNE      MPI
                pshs      a
-               lda       MPICTRL
+               lda       MPI.Slct
                sta       slot,u
-               lda       #RS232SLOT
-               sta       MPICTRL
+               lda       #DEVICESLOT
+               sta       MPI.Slct
                puls      a
                ENDC
                sta       A_RESET             soft reset (value not important)
@@ -609,7 +608,7 @@
                IFNE      MPI
                pshs      a
                lda       slot,u
-               sta       MPICTRL
+               sta       MPI.Slct
                puls      a
                ENDC
                rts       
@@ -623,9 +622,9 @@
 * Note, this routine currently doesn't timeout
 ioread                   
                IFNE      MPI
-               lda       MPICTRL
+               lda       MPI.Slct
                sta       slot,u
-               lda       #RS232SLOT
+               lda       #DEVICESLOT
                sta       $FF7F
                ENDC
 r@             lda       A_STATUS            get status byte
@@ -635,7 +634,7 @@
                IFNE      MPI
                pshs      b
                ldb       slot,u
-               stb       MPICTRL
+               stb       MPI.Slct
                puls      b,pc
                ELSE
                rts       
@@ -648,10 +647,10 @@
 iowrite                  
                IFNE      MPI
                pshs      d
-               ldb       MPICTRL
+               ldb       MPI.Slct
                stb       slot,u
-               ldb       #RS232SLOT
-               stb       MPICTRL
+               ldb       #DEVICESLOT
+               stb       MPI.Slct
                ELSE
                pshs      a                   save byte to write
                ENDC
@@ -662,7 +661,7 @@
                puls      d                   get byte
                sta       A_TXD               save to ACIA data port
                lda       slot,u
-               sta       MPICTRL
+               sta       MPI.Slct
                ELSE
                puls      a                   get byte
                sta       A_TXD               save to ACIA data port